==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/jabber_protocol/jabber-contact-details.h <==
/*
 * %kadu copyright begin%
 * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2009, 2010 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009, 2010 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef JABBER_CONTACT_DETAILS_H
#define JABBER_CONTACT_DETAILS_H

class QDomDocument;
class QDomElement;

#include <xmpp_rosteritem.h>

#include "contacts/contact.h"
#include "contacts/contact-details.h"
#include "contacts/contact-shared.h"

class JabberContactDetails : public ContactDetails
{
	Q_OBJECT

	PROPERTY_DEC(XMPP::Subscription, ContactSubscription)

public:
	explicit JabberContactDetails(ContactShared *contactShared, QObject *parent = 0);
	virtual ~JabberContactDetails();

	virtual void store();
	
	PROPERTY_DEF(XMPP::Subscription, subscription, setSubscription, ContactSubscription)

};

#endif // JABBER_CONTACT_DETAILS_H

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/jabber_protocol/jabber-contact-details.h <==
/*
 * %kadu copyright begin%
 * Copyright 2009, 2010, 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2009, 2010 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2009 Bartłomiej Zimoń (uzi18@o2.pl)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef JABBER_CONTACT_DETAILS_H
#define JABBER_CONTACT_DETAILS_H

class QDomDocument;
class QDomElement;

#include <xmpp_rosteritem.h>

#include "contacts/contact-details.h"
#include "contacts/contact.h"

class JabberContactDetails : public ContactDetails
{
	PROPERTY_DEC(XMPP::Subscription, ContactSubscription)
	PROPERTY_DEC(bool, IgnoreNextStatusChange)

public:
	explicit JabberContactDetails(ContactShared *contactShared);
	virtual ~JabberContactDetails();

	PROPERTY_DEF(XMPP::Subscription, subscription, setSubscription, ContactSubscription)
	PROPERTY_DEF(bool, ignoreNextStatusChange, setIgnoreNextStatusChange, IgnoreNextStatusChange)

};

#endif // JABBER_CONTACT_DETAILS_H
